import smtplib

def spam(subject,message):
	server = smtplib.SMTP('smtp.gmail.com',587)
	server.login('unknownannei@gmail.com',r'unknownselva')
	server.sendmail('unknownannei@gmail.com','anupamkris13262@gmail.com',
		"Subject : {}\n\n{}".format(subject,message))
	server.quit()
	return "Success"

print("Welcome to UnknownAnnei Spam corporation")
print("Use \nfrom unknownannei import spam \nto send spams")
print("Copying of this work or misusing will lead to the feel of machetes on their necks")
print("Visit Saidapet and donate us!")


from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="unknownannei",
    version="1.4.1",
    description="Forbidden!",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/",
    author="SaidapetSelva",
    author_email="unknownannei@unknownmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["unknownannei"],
    include_package_data=True,
        # entry_points={
    #     "console_scripts": [
    #         "weather-reporter=weather_reporter.cli:main",
    #     ]
    # },
)